@@ -219,11 +219,11 @@ def query_task_log(task_id, n):
         if len_cc > n:
             contents = contents[-n:len_cc]
             for content in contents:
-                print(content)
+                print(content['message'])
         else:
             contents = contents[len_c:len_cc]
             for content in contents:
-                print(content)
+                print(content['message'])
     else:
         print("Waiting log output, Please try it again in 10 seconds...")
 
